@@ -13,6 +13,11 @@ import org.gnu.glib.Type;
  *
  */
 public class CanvasBpath extends CanvasShape {
+
+	public CanvasBpath(CanvasGroup group) {
+		super(group, gnome_canvas_bpath_get_type());
+	}
+	
 	/**
 	 * Constructs an instance of CanvasBpath from a native widget resource.
 	 * @param handle The handle to the native widget.
@@ -21,9 +26,6 @@ public class CanvasBpath extends CanvasShape {
 		super(handle);
 	}
 
-	protected void noopInit() {
-	}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
